==> sghi_core-0.3.36.tar.gz: lib/afya_moja_core/src/presentation/facility/search_facility_item.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:sghi_core/afya_moja_core/src/app_asset_strings.dart';
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/buttons.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/facility/custom_chip.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/text_themes.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/user_feed/src/domain/value_objects/colors.dart';

class SearchFacilityItem extends StatelessWidget {
  const SearchFacilityItem({
    super.key,
    required this.isOpen,
    required this.facilityName,
    required this.facilityLocation,
    required this.showBookButton,
    this.onMoreInfoPressed,
    this.onBookPressed,
  });
  final bool isOpen;
  final String facilityName;
  final String facilityLocation;
  final bool showBookButton;
  final VoidCallback? onMoreInfoPressed;
  final VoidCallback? onBookPressed;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: const BorderRadius.all(
          Radius.circular(10.0),
        ),
        border: Border.all(
          color: primaryPurpleColor.withOpacity(.3),
        ),
        color: primaryPurpleColor.withOpacity(.1),
      ),
      padding: const EdgeInsets.all(16.0),
      child: Column(
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              SvgPicture.asset(
                facilityBuildingIcon,
                width: 80,
                height: 80,
              ),
              smallHorizontalSizedBox,
              Flexible(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        Flexible(
                          child: Column(
                            children: <Widget>[
                              Text(
                                facilityName,
                                style: boldSize18Text(
                                  primaryPurpleColor,
                                ),
                                maxLines: 1,
                                overflow: TextOverflow.ellipsis,
                              ),
                              smallVerticalSizedBox,
                              Row(
                                children: <Widget>[
                                  const Icon(
                                    Icons.location_on_outlined,
                                    color: primaryPurpleColor,
                                    size: 18,
                                  ),
                                  Flexible(
                                    child: Text(
                                      facilityLocation,
                                      style: normalSize14Text(
                                        grey1TextColor,
                                      ),
                                      maxLines: 1,
                                      overflow: TextOverflow.ellipsis,
                                    ),
                                  ),
                                ],
                              ),
                            ],
                          ),
                        ),
                        smallHorizontalSizedBox,
                        // facility status chip
                        CustomChip(
                          title: isOpen ? openString : closedString,
                          backgroundColor: isOpen
                              ? greenColor.withOpacity(.3)
                              : reactionIconRedColor.withOpacity(.3),
                          textColor: isOpen ? greenColor : redColor,
                        ),
                      ],
                    ),
                    smallVerticalSizedBox,
                    Row(
                      children: <Widget>[
                        CustomChip(
                          title: preEpString,
                          backgroundColor: primaryPurpleColor.withOpacity(.3),
                          textColor: primaryPurpleColor,
                        ),
                        smallHorizontalSizedBox,
                        CustomChip(
                          title: arTString,
                          backgroundColor: primaryPurpleColor.withOpacity(.3),
                          textColor: primaryPurpleColor,
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            ],
          ),
          smallVerticalSizedBox,
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Expanded(
                child: MyAfyaHubPrimaryButton(
                  text: moreInfoString,
                  textColor: primaryPurpleColor,
                  buttonColor: primaryPurpleColor.withOpacity(.3),
                  customRadius: 8.0,
                  borderColor: Colors.transparent,
                  customPadding: const EdgeInsets.symmetric(
                    horizontal: 10.0,
                    vertical: 13.0,
                  ),
                  onPressed: onMoreInfoPressed,
                ),
              ),
              if (showBookButton)
                Expanded(
                  child: MyAfyaHubPrimaryButton(
                    text: bookString,
                    textColor: whiteColor,
                    buttonColor: primaryPurpleColor,
                    customRadius: 8.0,
                    customPadding: const EdgeInsets.symmetric(
                      horizontal: 10.0,
                      vertical: 13.0,
                    ),
                    onPressed: onBookPressed,
                  ),
                ),
            ],
          ),
        ],
      ),
    );
  }
}

==> sghi_core-0.3.37.tar.gz: lib/afya_moja_core/src/presentation/facility/search_facility_item.dart <==
import 'package:flutter/material.dart';
import 'package:sghi_core/afya_moja_core/src/app_strings.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/buttons.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/facility/custom_chip.dart';
import 'package:sghi_core/afya_moja_core/src/presentation/text_themes.dart';
import 'package:sghi_core/shared_themes/spaces.dart';
import 'package:sghi_core/user_feed/src/domain/value_objects/colors.dart';

class SearchFacilityItem extends StatelessWidget {
  const SearchFacilityItem({
    super.key,
    required this.isOpen,
    required this.facilityName,
    required this.facilityLocation,
    required this.showBookButton,
    this.onMoreInfoPressed,
    this.onBookPressed,
  });
  final bool isOpen;
  final String facilityName;
  final String facilityLocation;
  final bool showBookButton;
  final VoidCallback? onMoreInfoPressed;
  final VoidCallback? onBookPressed;

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: const BorderRadius.all(Radius.circular(10)),
        border: Border.all(color: primaryPurpleColor.withOpacity(.3)),
        color: primaryPurpleColor.withOpacity(.1),
      ),
      padding: const EdgeInsets.all(16),
      child: Column(
        children: <Widget>[
          Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              Flexible(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Row(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: <Widget>[
                        Flexible(
                          child: Column(
                            children: <Widget>[
                              Text(
                                facilityName,
                                style: boldSize18Text(primaryPurpleColor),
                                maxLines: 1,
                                overflow: TextOverflow.ellipsis,
                              ),
                              smallVerticalSizedBox,
                              Row(
                                children: <Widget>[
                                  const Icon(
                                    Icons.location_on_outlined,
                                    color: primaryPurpleColor,
                                    size: 18,
                                  ),
                                  Flexible(
                                    child: Text(
                                      facilityLocation,
                                      style: normalSize14Text(grey1TextColor),
                                    ),
                                  ),
                                ],
                              ),
                            ],
                          ),
                        ),
                        smallHorizontalSizedBox,
                        // facility status chip
                        CustomChip(
                          title: isOpen ? openString : closedString,
                          backgroundColor: isOpen
                              ? greenColor.withOpacity(.3)
                              : reactionIconRedColor.withOpacity(.3),
                          textColor: isOpen ? greenColor : redColor,
                        ),
                      ],
                    ),
                    smallVerticalSizedBox,
                  ],
                ),
              ),
            ],
          ),
          smallVerticalSizedBox,
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Expanded(
                child: MyAfyaHubPrimaryButton(
                  text: moreInfoString,
                  textColor: primaryPurpleColor,
                  buttonColor: primaryPurpleColor.withOpacity(.3),
                  customRadius: 8,
                  borderColor: Colors.transparent,
                  customPadding:
                      const EdgeInsets.symmetric(horizontal: 10, vertical: 13),
                  onPressed: onMoreInfoPressed,
                ),
              ),
              if (showBookButton)
                Expanded(
                  child: MyAfyaHubPrimaryButton(
                    text: bookString,
                    textColor: whiteColor,
                    buttonColor: primaryPurpleColor,
                    customRadius: 8,
                    customPadding: const EdgeInsets.symmetric(
                      horizontal: 10,
                      vertical: 13,
                    ),
                    onPressed: onBookPressed,
                  ),
                ),
            ],
          ),
        ],
      ),
    );
  }
}
